Kylie
=====

Kylie provides mappings between JSON data structures and Python objects. It
provides a reasonable amount of power with only a tiny bit of magic, and it has
100% code coverage.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage
   kylie
   contributing
   authors
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

